@@ -17,6 +17,7 @@
 # along with django-testscenarios.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
+import django
 
 from django.db import models, transaction
 from django.test import (
@@ -30,6 +31,10 @@ from django_testscenarios.ubertest import (
     TransactionTestCaseWithScenarios)
 
 
+if hasattr(django, 'setup'):
+    django.setup()
+
+
 class TestModel(models.Model):
     """
     Model for testing database configuration/initialization
